@@ -4,7 +4,7 @@
 # In[1]:
 
 
-version = '0.33'
+version = '0.36'
 
 import re
 import tempfile
@@ -17,13 +17,13 @@ import base64
 
 # # Helper Functions
 
-# In[2]:
+# In[79]:
 
 
 get_ipython().run_cell_magic('javascript', '', 'var nb = IPython.notebook;\nvar kernel = IPython.notebook.kernel;\nvar command = "file_name = \'" + nb.notebook_path + "\'";\nkernel.execute(command);')
 
 
-# In[3]:
+# In[80]:
 
 
 def isnotebook():
@@ -34,7 +34,7 @@ def isnotebook():
     return False
 
 
-# In[4]:
+# In[81]:
 
 
 def is_testing():
@@ -48,7 +48,7 @@ def is_testing():
 # In[5]:
 
 
-def jprint(*args):
+def testPrint(*args):
     if is_testing():
         print(*args)
 
@@ -128,25 +128,25 @@ def sListFilter(l, re_include=".*", re_exclude='^\b$'):
 # In[12]:
 
 
-jprint(sListFilter(['good x', 'other good x', 'without the letter before y']))
+testPrint(sListFilter(['good x', 'other good x', 'without the letter before y']))
 
 
 # In[13]:
 
 
-jprint(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
+testPrint(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
 # In[14]:
 
 
-jprint(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
+testPrint(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
 # In[15]:
 
 
-jprint(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
+testPrint(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
 # # Text files
@@ -191,25 +191,25 @@ def sListFilter(listOfStrings, re_include=".*", re_exclude='^\b$'):
 # In[19]:
 
 
-jprint(sListFilter(['good x', 'other good x', 'without the letter before y']))
+testPrint(sListFilter(['good x', 'other good x', 'without the letter before y']))
 
 
 # In[20]:
 
 
-jprint(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
+testPrint(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
 # In[21]:
 
 
-jprint(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
+testPrint(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
 # In[22]:
 
 
-jprint(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
+testPrint(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
 # In[23]:
@@ -235,7 +235,7 @@ def imread(path):
     return img[:, :, [2, 1, 0]] # This converts the cv2 colors to RGB
 
 def imsread(paths):
-    if os.path.isdir(paths):
+    if isinstance(paths, str) and os.path.isdir(paths):
         return [imread(path) for path in fiFindByWildcard(os.path.join(paths, "*.png"))]
     assert isinstance(paths, list) or isinstance(paths, tuple), type(paths)
     return [imread(path) for path in paths]
@@ -254,8 +254,11 @@ def impad(img, top=0, bottom=0, left=0, right=0, color=255):
 # In[25]:
 
 
-def imshow(array):
+def imshow(array, scale=1):
     array = imread(array)
+    if scale > 1:
+        array = imscaleNN(array, scale)
+        
     if isnotebook():
         display(Image.fromarray(array))
     else:
@@ -560,7 +563,7 @@ if is_testing():
 
 def jnImgToHtmlB64(img):
     img = imread(img)
-    _, encimg = cv2.imencode('.png', img)
+    _, encimg = cv2.imencode('.png', img[:, :, [2, 1, 0]])
     imgB64 = base64.b64encode(encimg).decode('utf-8')
     img_tag = '<img src="data:image/png;base64,{0}" style="display:block; margin:0 auto;">'.format(imgB64)
     return img_tag
@@ -579,7 +582,7 @@ def jnImageRow(imgs, names=None, width=100):
     display(HTML(html))
 
 
-# In[79]:
+# In[55]:
 
 
 if is_testing():
@@ -597,24 +600,91 @@ if is_testing():
 
 # # Shell
 
-# In[57]:
+# In[82]:
 
 
 def shell(cmd):
     result = subprocess.run(cmd, shell=True, stdout=subprocess.PIPE)
-    return result.stdout.decode()
+    out = result.stdout.decode()
+    
+    if len(out) > 0 and out[-1] == "\n":
+        out = out[:-1]
+        
+    return out
+
+
+# # GIT
+
+# In[58]:
+
+
+def gitGetHash():
+    return shell('git rev-parse HEAD').strip()
+
+testPrint(gitGetHash())
+
+
+# In[59]:
+
+
+def gitGetBranch():
+    return shell('git rev-parse --abbrev-ref HEAD').strip()
+
+testPrint(gitGetBranch())
+
+
+# In[60]:
+
+
+def gitGetMessage():
+    return shell('git log --format=%B -n 1 HEAD').strip()
+
+testPrint(gitGetMessage())
+
+
+# In[61]:
+
+
+def gitGetAllFiles():
+    return shell('git ls-tree -r --name-only HEAD').split("\n")
+
+testPrint(gitGetAllFiles())
+
+
+# In[62]:
+
+
+def gitListByTime(path=None):
+    cd = '' if path is None else 'cd ' + path + ' &&'
+    
+    _time = lambda x: shell(cd + 'git log -1 --format="%ad" --date=raw -- {filename}'.format(filename=x))
+    paths = shell(cd + 'git ls-tree -r --name-only HEAD').split("\n")
+    times = list(map(_time, paths))
+    
+    return [path for _, path in sorted(zip(times, paths))]
+    
+testPrint(gitListByTime()[-3:])
+
+
+# In[84]:
+
+
+def shellSortDirsBySize():
+    return shell('du -h | sort -h')
+
+testPrint(shellSortDirsBySize())
 
 
 # # Package Files
 
-# In[58]:
+# In[ ]:
 
 
 if is_testing():
     package_files = {}
 
 
-# In[59]:
+# In[ ]:
 
 
 def shell(cmd):
@@ -622,7 +692,7 @@ def shell(cmd):
     return result.stdout.decode()
 
 
-# In[60]:
+# In[ ]:
 
 
 if is_testing():
@@ -654,7 +724,7 @@ setup(
 )""".format(requirements=", ".join(["'" + r + "'" for r in requirements]), version=version)
 
 
-# In[61]:
+# In[ ]:
 
 
 if is_testing():
@@ -664,7 +734,7 @@ description-file = README.md
 """
 
 
-# In[62]:
+# In[ ]:
 
 
 if is_testing():
@@ -687,14 +757,14 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE."""
 
 
-# In[63]:
+# In[ ]:
 
 
 if is_testing():
     package_files['README.md'] = ""
 
 
-# In[64]:
+# In[ ]:
 
 
 if is_testing():
@@ -708,7 +778,7 @@ if is_testing():
 
 
 
-# In[65]:
+# In[ ]:
 
 
 if is_testing():
@@ -719,7 +789,7 @@ lx/__init__.py
 """
 
 
-# In[66]:
+# In[ ]:
 
 
 if is_testing():
